@@ -4,7 +4,7 @@
 #' by independent variables in a model.
 #'
 #' @param x A linear model or an ANOVA object.
-#' @param method Name of the method (underlying test) that should be performend
+#' @param method Name of the method (underlying test) that should be performed
 #' to check the homogeneity of variances. May either be \code{"bartlett"} for
 #' the Bartlett test (assuming normal distributed samples or groups),
 #' \code{"fligner"} for the Fligner-Killeen test (rank-based, non-parametric test),
@@ -15,6 +15,8 @@
 #' @return Invisibly returns the p-value of the test statistics. A p-value
 #' < 0.05 indicates a significant difference in the variance between the groups.
 #'
+#' @note There is also a \href{https://easystats.github.io/see/articles/performance.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#'
 #' @examples
 #' model <- lm(len ~ supp + dose, data = ToothGrowth)
 #' check_homogeneity(model)
@@ -76,7 +78,10 @@ check_homogeneity.default <- function(x, method = c("bartlett", "fligner", "auto
     "fligner" = "Fligner-Killeen Test"
   )
 
-  if (p.val < 0.05) {
+  if (is.na(p.val)) {
+    warning(paste0("Could not perform ", method.string, "."), call. = FALSE)
+    invisible(NULL)
+  } else if (p.val < 0.05) {
     insight::print_color(sprintf("Warning: Variances differ between groups (%s, p = %.3f).\n", method.string, p.val), "red")
   } else {
     insight::print_color(sprintf("OK: Variances in each of the groups are the same (%s, p = %.3f).\n", method.string, p.val), "green")
