@@ -19,7 +19,7 @@
 #'   for logit-link and 1 for probit-link. For poisson-models, the
 #'   residual variance is based on log-normal approximation, similar to
 #'   the \emph{distribution-specific variance} as described in
-#'   \code{\link[insight]{get_variance}}.
+#'   \code{?insight::get_variance}.
 #'
 #'
 #' @examples
@@ -48,7 +48,7 @@ r2_mckelvey.default <- function(model) {
   faminfo <- insight::model_info(model)
   n <- insight::n_obs(model)
 
-  if (faminfo$is_binomial | faminfo$is_ordinal) {
+  if (faminfo$is_binomial | faminfo$is_ordinal | faminfo$is_multinomial) {
     dist.variance <- switch(
       faminfo$link_function,
       probit = 1,
